@@ -1577,6 +1577,10 @@ class TestAltGuessings(TestCase):
         alts = map.get_alts_list()
         self.assertEqual([('cat', [['cat', 'cat_1']]), ('dog', [['dog', 'dog_1']])], alts)
 
+    def test_simple_case_sans_underscore(self):
+        map = GridMap((0, 0, 32, 32), (16, 16), ['cat', 'dog', 'cat1', 'dog1'])
+        alts = map.get_alts_list()
+        self.assertEqual([('cat', [['cat', 'cat1']]), ('dog', [['dog', 'dog1']])], alts)
 
     def test_shapely_box(self):
         map = GridMap((0, 0, 64, 32), (16, 16), ['cat_top', 'potato', 'cat_top_1', 'grapefruit',
