@@ -636,7 +636,7 @@ class RenamedResource(ResourceBase):
 
 class MapBase(object):
     def get_alts_list(self):
-        alt_re = re.compile('_[0-9]$')
+        alt_re = re.compile('_?[0-9]$')
         side_re = re.compile('_(front|back|side|left|right|top|bottom|head|foot)$')
 
         groups = {}
